Module error

Module error 

Error type.

Enums

Error
Error type.

Constants

GLV_PRICING_GLV_VALUE_TO_MARKET_TOKEN_ERROR
Error message indicating a failure to convert a GLV value to a market token amount.
GLV_PRICING_MARKET_TOKEN_TO_GLV_VALUE_ERROR
Error message indicating a failure to convert a market token amount to a GLV value.
GLV_PRICING_NEGATIVE_POOL_VALUE_ERROR
Error message indicating a negative pool value during GLV pricing.