Error type.
Enums
- Error
- Error type.
Constants
- GLV_
PRICING_ GLV_ VALUE_ TO_ MARKET_ TOKEN_ ERROR - Error message indicating a failure to convert a GLV value to a market token amount.
- GLV_
PRICING_ MARKET_ TOKEN_ TO_ GLV_ VALUE_ ERROR - Error message indicating a failure to convert a market token amount to a GLV value.
- GLV_
PRICING_ NEGATIVE_ POOL_ VALUE_ ERROR - Error message indicating a negative pool value during GLV pricing.